==> verse-1.1.tar.gz: verse-1.1/README.md <==
# Verse

> Make project individual tools easier ! Verse help you to create project specific alias and environment modification thanks to a simple file

## How does it work ?

- Create a verse folder inside your project folder.
- create and edit a Versefile.
- Inside this one write instructions:

### NAME (name)
Set a project name. Verse will then use this to customize your prompt.

```
NAME MoonApp
```

### ALIAS (name, command)
Create a custom alias for your project.
WARNING this command will be executed in a subshell, so exit will not exit your shell.

```
ALIAS dev react-native-run android --settings moonapp-settings-dev.json
```

### ENV

- ADD (key, value)
Modify content of key in env to append value.

```
ENV ADD ANDROID_PATH ./android-sdk
```

- SET (key, value)
Modify content of key in env by value.

```
ENV SET VERSION 4
```

### RUN (command)
This command will be run when executing `verse run` (multiples are allowed)
```
RUN mongod --port 5542 &
```

### SETUP (command)
This command will be run when executing `verse setup` (multiples are allowed)
```
SETUP npm i
```

## There is also some customization commands

### PRINT (messgage)
Print a message
```
PRINT MoonLanding project !
```

### DESC (description)
Must be placed before `ALIAS`
Add a description for an alias
```
DESC use to clean npm packages
ALIAS rm -rf nodes-modules
```

### FORE (r, g, b)
Used to set the prompt foreground
```
FORE 255 255 255
```

### BACK (r, g, b)
Used to set the prompt background
```
FORE 162 35 173
```

## Verse CLI

`verse {ROOTDIR, default=./verse}`

Launch verse with a optional path to a dir containing a Versefile

- `[arg]` is mandatory, `{arg}` is optional

`verse [OPTIONS]`

Options:
- `run {ROOTDIR}`
> Execute all RUN commands of Versefile

- `setup {ROOTDIR}`
> Execute all SETUP commands of Versefile

- `list {ROOTDIR}`
> Display all commands in Versefile

- `info {ROOTDIR}`
> Display Versefile info

- `help`
> Display help

## Important informations:
- All command and alias will be executed in a subshell, so ALIAS exit will not exit your shell.
- All path will be replaced by `VERSEFILE_FOLDER_FULL_PATH`+path except these starting by `/`

## TODO
> - make `ENV` directives also used by `run` et `setup`
> - Example

==> verse-1.3.tar.gz: verse-1.3/README.md <==
# Verse

> Make project individual tools easier ! Verse help you to create project specific alias and environment modification thanks to a simple file

## How does it work ?

- Create a verse folder inside your project folder.
- create and edit a Versefile.
- Inside this one write instructions:

### NAME (name)
Set a project name. Verse will then use this to customize your prompt.
```
NAME MoonApp
```

### ALIAS (name, command)
Create a custom alias for your project.
```
ALIAS dev react-native-run android --settings moonapp-settings-dev.json
```

### ENV
> ADD (key, value)
Modify content of key in env to append value.
```
ENV ADD ANDROID_PATH ./android-sdk
```

> SET (key, value)
Modify content of key in env by value.
```
ENV SET VERSION 4
```

### RUN (command)
This command will be run when executing `verse run` (multiples are allowed)
```
RUN mongod --port 5542 &
```

### SETUP (command)
This command will be run when executing `verse setup` (multiples are allowed)
```
SETUP npm i
```

## There is also some customization commands

### PRINT (messgage)
Print a message
```
PRINT MoonLanding project !
```

### DESC (description)
Must be placed before `ALIAS`\
Add a description for an alias
```
DESC use to clean npm packages
ALIAS rm -rf nodes-modules
```

### FORE (r, g, b)
Used to set the prompt foreground
```
FORE 255 255 255
```

### BACK (r, g, b)
Used to set the prompt background
```
FORE 162 35 173
```

## Verse CLI

`verse {ROOTDIR, default=./verse}`

Launch verse with a optional path to a dir containing a Versefile

> `[arg]` is mandatory, `{arg}` is optional

`verse [OPTIONS]`

Options:
- `run {ROOTDIR}` Execute all RUN commands of Versefile
- `setup {ROOTDIR}` Execute all SETUP commands of Versefile
- `list {ROOTDIR}` Display all commands in Versefile
- `info {ROOTDIR}` Display Versefile info
- `help` Display help

## Important informations:
- All command and alias will be executed in a subshell, so ALIAS exit will not exit your shell.
- All path will be replaced by `VERSEFILE_FOLDER_FULL_PATH`+path except these starting by `/`

## TODO
> - make `ENV` directives also used by `run` et `setup`
> - Example
